{% extends 'base.html' %}

{% block content %}

    <br>

    <h4>Unable to render the report</h4>
    <p class="card-subtitle mb-2 text-muted">Please indicate a valid report identifier.</p>
    <br>
    
    
{% endblock %}