<!doctype html>
<html lang="en">
  <head>
    <!-- Required meta tags -->
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">
    
    {% include 'utils-web/imports.html' %}
    
    <link rel="icon" type="image/x-icon" href="../static/fixout2.png">
    
    <title>{% block title %} FixOut {% endblock %}</title>
  </head>
  <body>
    
    <div class="container">
      <nav id="navbar-example2" class="navbar navbar-light bg-light">
        <a class="navbar-brand">{{ report_details.report_name }}</a>
        <ul class="nav nav-pills">
          <li class="nav-item">
            <a class="nav-link" href="http://fixout.fr"><img src="{{url_for('static', filename='fixout.png')}}"  width="96" alt="FixOut"></a>
          </li>
        </ul>
      </nav>
      
    <div class="container">
      

      {% block content %} {% endblock %}
      
      <hr>
    </div>
    
  </div>

    {% include 'utils-web/scripts.html' %}   

  </body>
  </html>