<div class="alert alert-warning" role="alert">
    <h4 class="alert-heading"> Not available</h4>
    <p>This functionality is not available in this version of FixOut</p>
    <hr>
    <p class="mb-0">Check out our website to find out a version that suits your case. → <a href="http://fixout.fr/products">fixout.fr</a></p>
</div>